@@ -1,4 +1,4 @@
 #[cfg(esp_idf_comp_esp_http_client_enabled)]
 pub mod client;
-#[cfg(esp_idf_comp_esp_http_server_enabled)]
+#[cfg(all(esp_idf_comp_esp_http_server_enabled, feature = "std"))]
 pub mod server;
